.. include:: description.rst
.. include:: resources.rst
.. include:: installation.rst
.. include:: examples.rst
.. include:: advanced_usage.rst
.. include:: module_documentation.rst
.. include:: indices_and_tables.rst

